Crate proto_tower_util

Crate proto_tower_util 

Proto-tower-util is a collection of utilities that are used across the proto-tower project.

Modules

debug

Structs

AsyncReadToBuf
A helper to read data within a timeout This handles both the cases where the read(&mut buffer) may not return any data or constantly return len 0
DebugIoLayer
I/O Pattern Layer takes a (read, write) (as it would for servers) and will also send down a (read, write) pair (as you would do for clients)
DebugIoService
NextTimeout
TestIoService
A service you can conveniently use to validate layers that interact with AsyncReadExt and AsyncWriteExt
TimeoutCounter

Enums

CountOrDuration
ZeroReadBehaviour

Traits

BytesMutHelper
WriteTo

Functions

sx_rx_chans