AsyncReadToBuf

Struct AsyncReadToBuf 

pub struct AsyncReadToBuf<const S: usize> { /* private fields */ }
A helper to read data within a timeout This handles both the cases where the read(&mut buffer) may not return any data or constantly return len 0

Implementations

Source

impl AsyncReadToBuf<1024>

pub const fn new_1024( zero_read_behaviour: ZeroReadBehaviour, ) -> AsyncReadToBuf<1024>

Source

impl<const S: usize> AsyncReadToBuf<S>

pub const fn new(zero_read_behaviour: ZeroReadBehaviour) -> Self

pub async fn read_until<READ: AsyncReadExt + Unpin + Send + 'static>( &self, reader: &mut BufReader<READ>, byte: u8, ) -> Vec<u8>

pub async fn read_with_timeout_bytes<READ: AsyncReadExt + Unpin + Send + 'static>( &self, reader: &mut READ, _writer: &mut BytesMut, timeout: Duration, desired_size: Option<usize>, )

pub async fn read_with_timeout<READ: AsyncReadExt + Unpin + Send + 'static>( &self, reader: &mut READ, timeout: Duration, desired_size: Option<usize>, ) -> Vec<u8>