pub struct TimeoutCounter {
pub tick_rate: Duration,
pub total_count: u64,
pub current_count: AtomicU64,
pub start_time: RwLock<Instant>,
}Fields
tick_rate: Durationtotal_count: u64current_count: AtomicU64start_time: RwLock<Instant>Implementations
Sourceimpl TimeoutCounter
impl TimeoutCounter
Sourcepub fn new(interval: CountOrDuration, timeout: CountOrDuration) -> Self
pub fn new(interval: CountOrDuration, timeout: CountOrDuration) -> Self
TODO this can actually be a fixed timeout with default of 1 increments (assuming the future gets cancelled) Then the second part would always be duration and the tick increment would be num or duration
pub fn next_timeout(&self) -> NextTimeout ⓘ
pub fn reset(&self)