Proto-tower-util is a collection of utilities that are used across the proto-tower project.
Modules
Structs
- Async
Read ToBuf - A helper to read data within a timeout This handles both the cases where the read(&mut buffer) may not return any data or constantly return len 0
- Debug
IoLayer - I/O Pattern Layer takes a (read, write) (as it would for servers) and will also send down a (read, write) pair (as you would do for clients)
- Debug
IoService - Next
Timeout - Test
IoService - A service you can conveniently use to validate layers that interact with AsyncReadExt and AsyncWriteExt
- Timeout
Counter